@@ -19,6 +19,7 @@ from talos.client.compression.Compression import Compression
 from talos.thrift.transport.TSocket import TTransportException
 from talos.thrift.message.ttypes import MessageOffset
 from talos.client.ScheduleInfoCache import ScheduleInfoCache
+import traceback
 import logging
 
 
@@ -86,21 +87,24 @@ class SimpleConsumer:
         clientTimeout = self.consumerConfig.get_client_timeout()
         getMessageRequest.timeoutTimestamp = (Utils.current_time_mills() + clientTimeout)
 
-        getMessageResponse = GetMessageResponse()
-        getMessageResponse.messageBlocks = []
+        getMessageResponse = GetMessageResponse(messageBlocks=[])
         try:
             getMessageResponse = self.scheduleInfoCache.get_or_create_message_client(
                 topicAndPartition=self.topicAndPartition).get_message(getMessageRequest)
-        except TTransportException as tTransportException:
-            if not self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
-                self.logger.warn("can't connect to the host directly, refresh scheduleInfo and retry using url. "
-                                 + "The exception message is :" + tTransportException.message +
-                                 ". Ignore this if not frequently.")
-                self.scheduleInfoCache.update_schedule_info_cache()
-                getMessageResponse = self.messageClient.get_message(getMessageRequest)
+        except Exception as e:
+            if isinstance(e, TTransportException):
+                if self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
+                    self.logger.warn("can't connect to the host directly, refresh scheduleInfo and retry using url. "
+                                     + "The exception message is :" + e.message +
+                                     ". Ignore this if not frequently.")
+                    self.scheduleInfoCache.update_schedule_info_cache()
+                    getMessageResponse = self.messageClient.get_message(getMessageRequest)
+                else:
+                    self.logger.error("fetch message failed! ", str(traceback.format_exc()))
+                    raise e
             else:
-                self.logger.error("fetch message failed! ")
-                raise tTransportException
+                self.logger.error("fetch message failed! ", str(traceback.format_exc()))
+                raise e
 
         # update scheduleInfocache when request have been transfered and talos auto location was set up
         if self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
