@@ -91,10 +91,11 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             if self.logger.isEnabledFor:
                 self.logger.debug("Reading message from offset: " + str(self.startOffset.value) +
                                   " of partition: " + str(self.topicAndPartition.partitionId))
-
+            startFetchTime = Utils.current_time_mills()
             messageList = self.simpleConsumer.fetch_message(startOffset=self.startOffset.value,
                                                             maxFetchedNumber=self.consumerConfig.get_max_fetch_msg_num())
             self.lastFetchTime = Utils.current_time_mills()
+            self.consumerMetrics.mark_fetch_duration(self.lastFetchTime - startFetchTime)
 
             # return when no message got
             if not messageList or len(messageList) == 0:
@@ -105,10 +106,13 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             # Note: We guarantee the committed offset must be the messages that
             # have been processed by user 's MessageProcessor;
             self.finishedOffset = messageList[len(messageList) - 1].messageOffset
+            startProcessTime = Utils.current_time_mills()
             self.messageProcessor.process(messageList, self)
+            self.consumerMetrics.mark_process_duration(Utils.current_time_mills() - startProcessTime)
             self.startOffset.get_and_set(self.finishedOffset + 1)
             self.check_and_commit(True)
         except Exception as e:
+            self.consumerMetrics.mark_fetch_or_process_failed_times()
             if isinstance(e, GalaxyTalosException):
                 self.logger.error(e.errMsg)
             self.logger.error("Error when getting messages from topic: "
